-- Czech chart of accounts
-- Tomas.Fencl@centrum.cz
--    Kompletn tov osnova platn v roce 2001
--    Osnova m 2 msta pro tvorbu analytik
--
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1000', 'Dlouhodob nehmotn majetek','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1100', 'Zizovac vdaje','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1200', 'Nehmotn vsledky vzkumu a vvoje','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1300', 'Software','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1400', 'Oceniteln prva','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1800', 'Drobn dlouhodob nehmotn majetek','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1900', 'Ostatn dlouhodob nehmotn majetek','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2000', 'Dlouhodob Hmotn majetek odpisovan','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2100', 'Stavby','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2200', 'Samostatn movit vci a soubory movitch vc','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2500', 'Pstitelsk celky trvalch porost','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2600', 'Zkladn stdo a tan zvata','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2800', 'Drobn dlouhodob hmotn majetek','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2900', 'Ostatn dlouhodob hmotn majetek','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3000', 'Dlouhodob hmotn majetek neodpisovan','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3100', 'Pozemky','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3200', 'Umleck dla a sbrky','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4000', 'Pozen dlouhodobho nehmotnho a hmotnho majetku','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4100', 'Pozen dlouhodobho nehmotnho majetku','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4200', 'Pozen dlouhodobho hmotnho majetku','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5000', 'Poskytnut zlohy na dlouhodob nehmotn a hmotn majetek','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5100', 'Poskytnut zlohy na dlouhodob nehmotn majetek','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5200', 'Poskytnut zlohy na dlouhodob hmotn majetek','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6000', 'Dlouhodob finann majetek','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6100', 'Podlov cenn papry a vklady v podnicch s rozhodujcm','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6200', 'Podlov cenn papry a vklady v podnicch s podstatnm','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6300', 'Ostatn dlouhodob cenn papry a vklady','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6600', 'Pjky podnikm ve skupin','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6700', 'Ostatn pjky','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6900', 'Ostatn dlouhodob finann majetek','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7000', 'Oprvky k dlouhodobmu nehmotnmu majetku','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7100', 'Oprvky ke zizovacm vdajm','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7200', 'Oprvky k nehmotnm vsledkm vzkumu a vvoje','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7300', 'Oprvky k softwaru','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7400', 'Oprvky k ocenitelnm prvm','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7800', 'Oprvky k drobnmu dlouhodobmu nehmotnmu majetku','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7900', 'Oprvky k ostatnmu dlouhodobmu nehmotnmu majetku','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8000', 'Oprvky k dlouhodobmu hmotnmu majetku','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8100', 'Oprvky ke stavbm','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8200', 'Oprvky k samostatnm movitm vcem a souborm movitch vc','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8500', 'Oprvky k pstitelskm celkm trvalch porost','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8600', 'Oprvky k zkladnmu stdu a tanm zvatm','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8800', 'Oprvky k drobnmu dlouhodobmu hmotnmu majetku','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8900', 'Oprvky k ostatnmu dlouhodobmu hmotnmu majetku','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('9000', 'Opravn poloky k dlouhodobmu majetku','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('9100', 'Opravn poloka k dlouhodobmu nehmotnmu majetku','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('9200', 'Opravn poloka k dlouhodobmu hmotnmu majetku','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('9300', 'Opravn poloka k dlouhodobmu nedokonenmu nehmotnmu','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('9400', 'Opravn poloka k dlouhodobmu nedokonenmu hmotnmu','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('9500', 'Opravn poloka k poskytnutm zlohm','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('9600', 'Opravn poloka k dlouhodobmu finannmu majetku','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('9700', 'Opravn poloka k nabytmu majetku','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('9800', 'Oprvky k opravn poloce k nabytmu majetku','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('10000', 'Zsoby','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('11000', 'Materil','H','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('11100', 'Pozen materilu','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('11200', 'Materil na sklad','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('11900', 'Materil na cest','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('12000', 'Zsoby vlastn vroby','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('12100', 'Nedokonen vroba','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('12200', 'Polotovary vlastn vroby','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('12300', 'Vrobky','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('12400', 'Zvata','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('13000', 'Zbo','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('13100', 'Pozen zbo','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('13200', 'Zbo na sklad a v prodejnch','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('13900', 'Zbo na cest','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('19000', 'Opravn poloky k zsobm','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('19100', 'Opravn poloka k materilu','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('19200', 'Opravn poloka k nedokonen vrob','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('19300', 'Opravn poloka k polotovarm vlastn vroby','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('19400', 'Opravn poloka k vrobkm','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('19500', 'Opravn poloka ke zvatm','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('19600', 'Opravn poloka ke zbo','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('20000', 'Finann ty','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('21000', 'Penze','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('21100', 'Pokladna','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('21300', 'Ceniny','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('22000', 'ty v bankch','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('22100', 'Bankovn ty','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('22200', 'Bankovn ty klient','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('23000', 'Bn bankovn vry','H','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('23100', 'Krtkodob bankovn vry','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('23200', 'Eskontn vry','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('24000', 'Jin krtkodob finann vpomoci','H','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('24100', 'Emitovan krtkodob dluhopisy','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('24900', 'Ostatn krtkodob finann vpomoci','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('25000', 'Krtkodob finann majetek','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('25100', 'Majetkov cenn papry','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('25200', 'Vlastn akcie a vlastn obchodn podly','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('25300', 'Dlun cenn papry','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('25500', 'Vlastn dluhopisy','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('25600', 'Ostatn cenn papry','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('26000', 'Pevody mezi finannmi ty','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('26100', 'Penze na cest','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('29000', 'Opravn poloky ke krtkodobmu finannmu majetku','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('29100', 'Opravn poloka k majetkovm cennm paprm','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('29300', 'Opravn poloka k dlunm cennm paprm','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('30000', 'Ztovac vztahy','H','','H','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('31000', 'Pohledvky','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('31100', 'Odbratel','A','','A','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('31200', 'Smnky k inkasu','A','','A','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('31300', 'Pohledvky za eskontovan cenn papry','A','','A','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('31400', 'Poskytnut provozn zlohy','A','','A','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('31500', 'Ostatn pohledvky','A','','A','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('32000', 'Zvazky','H','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('32100', 'Dodavatel','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('32200', 'Smnky k hrad','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('32400', 'Pijat zlohy','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('32500', 'Ostatn zvazky','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('32600', ' Zvazky vi klientm','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('32700', ' Zvazky vi trhm','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('33000', 'Ztovn se zamstnanci a institucemi','H','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('33100', 'Zamstnanci','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('33300', 'Ostatn zvazky vi zamstnancm','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('33500', 'Pohledvky za zamstnanci','A','','A','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('33600', 'Ztovn s institucemi socilnho zabezpeen a zdravotnho','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34000', 'Ztovn dan a dotac','H','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34100', 'Da z pjm','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34200', 'Ostatn pm dan','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34300', 'Da z pidan hodnoty - ztovn','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34311', 'DPH 5% vstup','A','','L','AP_tax:IC_taxpart:IC_taxservice');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34312', 'DPH 22% vstup','A','','L','AP_tax:IC_taxpart:IC_taxservice');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34321', 'DPH 5% vstup','A','','L','AR_tax:IC_taxpart:IC_taxservice');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34322', 'DPH 22% vstup','A','','L','AR_tax:IC_taxpart:IC_taxservice');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34500', 'Ostatn dan a poplatky','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34600', 'Dotace ze sttnho rozpotu','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34700', 'Ostatn dotace','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('35000', 'Pohledvky ke spolenkm a sdruen','H','','A','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('35100', 'Pohledvky k podnikm ve skupin','A','','A','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('35300', 'Pohledvky za upsan vlastn kapitl','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('35400', 'Pohledvky za spolenky pi hrad ztrty','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('35500', 'Ostatn pohledvky za spolenky','A','','A','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('35800', 'Pohledvky k astnkm sdruen','A','','A','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('36000', 'Zvazky ke spolenkm a sdruen','H','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('36100', 'Zvazky k podnikm ve skupin','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('36400', 'Zvazky ke spolenkm pi rozdlovn zisku','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('36500', 'Ostatn zvazky ke spolenkm','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('36600', 'Zvazky ke spolenkm a lenm drustva ze zvisl','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('36700', 'Zvazky z upsanch nesplacench cennch papr a vklad','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('36800', 'Zvazky k astnkm sdruen','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('37000', 'Jin pohledvky a zvazky','H','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('37100', 'Odloen daov pohledvka a zvazek','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('37300', 'Nakoupen opce','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('37400', 'Prodan opce','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('37500', 'Pohledvky z emitovanch dluhopis','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('37700', ' Ztovn obchod','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('37800', 'Jin pohledvky','A','','A','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('37900', 'Jin zvazky','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('38000', 'Pechodn ty aktiv a pasv','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('38100', 'Nklady ptch obdob','A','','A','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('38200', 'Komplexn nklady ptch obdob','A','','A','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('38300', 'Vdaje ptch obdob','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('38400', 'Vnosy ptch obdob','A','','L','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('38500', 'Pjmy ptch obdob','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('38600', 'Kursov rozdly aktivn','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('38700', 'Kursov rozdly pasvn','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('38800', 'Dohadn ty aktivn','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('38900', 'Dohadn ty pasvn','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('39000', 'Opravn poloka k ztovacm vztahm a vnitn ztovn','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('39100', 'Opravn poloka k pohledvkm','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('39500', 'Vnitn ztovn','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('39800', 'Spojovac et pi sdruen','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('40000', 'Kapitlov ty a dlouhodob zvazky','H','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('41000', 'Zkladn kapitl a kapitlov fondy','H','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('41100', 'Zkladn kapitl','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('41200', 'Emisn io','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('41300', 'Ostatn kapitlov fondy','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('41400', 'Oceovac rozdly z pecenn majetku a zvazk','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('42000', 'Fondy ze zisku a peveden hospodsk vsledky','H','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('42100', 'Zkonn rezervn fond','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('42200', 'Nedliteln fond','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('42300', 'Statutrn fondy','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('42700', 'Ostatn fondy','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('42800', 'Nerozdlen zisk minulch let','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('42900', 'Neuhrazen ztrta minulch let','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('43000', 'Hospodsk vsledek','H','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('43100', 'Hospodsk vsledek ve schvalovacm zen','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('45000', 'Rezervy','H','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('45100', 'Rezervy zkonn','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('45400', 'Rezerva na kursov ztrty','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('45900', 'Ostatn rezervy','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('46000', 'Bankovn vry','H','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('46100', 'Bankovn vry','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('47000', 'Dlouhodob zvazky','H','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('47100', 'Dlouhodob zvazky k podnikm ve skupin','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('47300', 'Emitovan dluhopisy','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('47400', 'Zvazky z pronjmu','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('47500', 'Dlouhodob pijat zlohy','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('47800', 'Dlouhodob smnky k hrad','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('47900', 'Ostatn dlouhodob zvazky','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('49000', 'Individuln podnikatel','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('49100', 'et individulnho podnikatele','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('50000', 'Spotebovan nkupy','A','','E','AP_amount:IC_COGS');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('50100', 'Spoteba materilu','A','','E','AP_amount:IC_COGS');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('50200', 'Spoteba energie','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('50300', 'Spoteba ostatnch neskladovatelnch dodvek','A','','E','AP_amount:IC_COGS');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('50400', 'Prodan zbo','A','','E','AP_amount:IC_COGS');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('51000', 'Sluby','A','','E','AP_amount:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('51100', 'Opravy a udrovn','A','','E','AP_amount:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('51200', 'Cestovn','A','','E','AP_amount:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('51300', 'Nklady na reprezentaci','A','','E','AP_amount:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('51800', 'Ostatn sluby','A','','E','AP_amount:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('52000', 'Osobn nklady','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('52100', 'Mzdov nklady','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('52200', 'Pjmy spolenk a len drustva ze zvisl innosti','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('52300', 'Odmny lenm orgn spolenosti a drustva','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('52400', 'Zkonn sociln pojitn','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('52500', 'Ostatn sociln pojitn','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('52600', 'Sociln nklady individulnho podnikatele','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('52700', 'Zkonn sociln nklady','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('52800', 'Ostatn sociln nklady','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('53000', 'Dan a poplatky','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('53100', 'Da silnin','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('53200', 'Da z nemovitost','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('53800', 'Ostatn dan a poplatky','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('54000', 'Jin provozn nklady','A','','E','AP_amount:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('54100', 'Zstatkov cena prodanho dlouhodobho nehmotnho a hmotnho','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('54200', 'Prodan materil','A','','E','IC_COGS');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('54300', 'Dary','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('54400', 'Smluvn pokuty a roky z prodlen','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('54500', 'Ostatn pokuty a penle','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('54600', 'Odpis pohledvky','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('54800', 'Ostatn provozn nklady','A','','E','AP_amount:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('55000', 'Odpisy, rezervy a opravn poloky provoznch nklad','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('55100', 'Odpisy dlouhodobho nehmotnho a hmotnho majetku','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('55200', 'Tvorba zkonnch rezerv','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('55400', 'Tvorba ostatnch rezerv','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('55500', 'Ztovn komplexnch nklad ptch obdob','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('55700', 'Ztovn oprvky k opravn poloce k nabytmu majetku','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('55800', 'Tvorba zkonnch opravnch poloek','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('55900', 'Tvorba opravnch poloek','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('56000', 'Finann nklady','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('56100', 'Prodan cenn papry a vklady','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('56200', 'roky','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('56300', 'Kursov ztrty','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('56800', 'Ostatn finann nklady','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('57000', 'Rezervy a opravn poloky finannch nklad','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('57400', 'Tvorba rezerv','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('57900', 'Tvorba opravnch poloek','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('58000', 'Mimodn nklady','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('58100', 'Nklady na zmnu metody','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('58200', 'Manka a kody','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('58400', 'Tvorba rezerv','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('58800', 'Ostatn mimodn nklady','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('58900', 'Tvorba opravnch poloek','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('59000', 'Dan z pjm a pevodov ty','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('59100', 'Da z pjm z bn innosti - splatn','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('59200', 'Da z pjm z bn innosti - odloen','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('59300', 'Da z pjm z mimodn innosti - splatn','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('59400', 'Da z pjm z mimodn innosti - odloen','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('59500', 'Dodaten odvody dan z pjm','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('59600', 'Pevod podlu na hospodskm vsledku spolenkm','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('59700', 'Pevod provoznch nklad','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('59800', 'Pevod finannch nklad','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('60000', 'Trby za vlastn vkony a zbo','A','','I','AR_amount:IC_sale:IC_Income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('60100', 'Trby za vlastn vrobky','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('60200', 'Trby z prodeje slueb','A','','I','AR_amount:IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('60400', 'Trby za zbo','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('61000', 'Zmny stavu vnitropodnikovch zsob','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('61100', 'Zmna stavu nedokonen vroby','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('61200', 'Zmna stavu polotovar','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('61300', 'Zmna stavu vrobk','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('61400', 'Zmna stavu zvat','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('62000', 'Aktivace','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('62100', 'Aktivace materilu a zbo','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('62200', 'Aktivace vnitropodnikovch slueb','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('62300', 'Aktivace dlouhodobho nehmotnho majetku','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('62400', 'Aktivace dlouhodobho hmotnho majetku','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('64000', 'Jin provozn vnosy.','A','','I','AR_amount:IC_sale:IC_Income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('64100', 'Trby z prodeje dlouhodobho nehmotnho a hmotnho majetku','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('64200', 'Trby z prodeje materilu','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('64400', 'Smluvn pokuty a roky z prodlen','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('64600', 'Vnosy z odepsanch pohledvek','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('64800', 'Jin provozn vnosy','A','','I','AR_amount:IC_sale:IC_Income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('65000', 'Ztovn rezerv a opravnch poloek provoznch vnos','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('65200', 'Ztovn zkonnch rezerv','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('65400', 'Ztovn ostatnch rezerv','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('65500', 'Ztovn komplexnch nklad ptch obdob','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('65700', 'Ztovn oprvky k opravn poloce k nabytmu majetku','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('65800', 'Ztovn zkonnch opravnch poloek','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('65900', 'Ztovn opravnch poloek','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('66000', 'Finann vnosy','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('66100', 'Trby z prodeje cennch papr a vklad','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('66200', 'roky','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('66300', 'Kursov zisky','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('66500', 'Vnosy z dlouhodobho finannho majetku','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('66600', 'Vnosy z krtkodobho finannho majetku','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('66800', 'Ostatn finann vnosy','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('67000', 'Ztovn rezerv a opravnch poloek finannch vnos','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('67400', 'Ztovn rezerv','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('67900', 'Ztovn opravnch poloek','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('68000', 'Mimodn vnosy','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('68100', 'Vnosy ze zmny metody','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('68400', 'Ztovn rezerv','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('68800', 'Ostatn mimodn vnosy','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('68900', 'Ztovn opravnch poloek','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('69000', 'Pevodov ty','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('69700', 'Pevod provoznch vnos','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('69800', 'Pevod finannch vnos','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('70000', 'ty rozvan','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('70100', 'Poten et rozvan','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('70200', 'Konen et rozvan','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('71000', 'et zisk a ztrt','A','','A','');
--
insert into tax (chart_id,rate) values ((select id from chart where accno = '34311'),0.05);
insert into tax (chart_id,rate) values ((select id from chart where accno = '34312'),0.22);
insert into tax (chart_id,rate) values ((select id from chart where accno = '34321'),0.05);
insert into tax (chart_id,rate) values ((select id from chart where accno = '34322'),0.22);
--
update defaults set inventory_accno_id = (select id from chart where accno = '13200'), income_accno_id = (select id from chart where accno = '60000'), expense_accno_id = (select id from chart where accno = '50000'), fxgain_accno_id = (select id from chart where accno = '99998'), fxloss_accno_id = (select id from chart where accno = '99999'), curr = 'K ', weightunit = 'kg';
--
